pub struct RegisterContainerImageRequest {
pub digest: String,
pub label: String,
pub service_name: String,
}Fields
digest: StringThe digest of the container image to be registered.
label: StringThe label for the container image when it's registered to the container service.
Use a descriptive label that you can use to track the different versions of your registered container images.
Use the GetContainerImages action to return the container images registered to a Lightsail container service. The label is the <imagelabel> portion of the following image name example:
-
:container-service-1.<imagelabel>.1
If the name of your container service is mycontainerservice, and the label that you specify is mystaticwebsite, then the name of the registered container image will be :mycontainerservice.mystaticwebsite.1.
The number at the end of these image name examples represents the version of the registered container image. If you push and register another container image to the same Lightsail container service, with the same label, then the version number for the new registered container image will be 2. If you push and register another container image, the version number will be 3, and so on.
service_name: StringThe name of the container service for which to register a container image.